# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum
import typing
import uuid as _uuid

import winrt.system
from winrt import _winrt_microsoft_ui_xaml_controls

if typing.TYPE_CHECKING:
    import winrt.windows.foundation as windows_foundation

__all__ = [
    "AnnotatedScrollBarScrollingEventKind",
    "AppBarClosedDisplayMode",
    "AutoSuggestionBoxTextChangeReason",
    "BackgroundSizing",
    "CalendarViewDisplayMode",
    "CalendarViewSelectionMode",
    "CandidateWindowAlignment",
    "CharacterCasing",
    "ClickMode",
    "ColorPickerHsvChannel",
    "ColorSpectrumComponents",
    "ColorSpectrumShape",
    "ComboBoxSelectionChangedTrigger",
    "CommandBarDefaultLabelPosition",
    "CommandBarDynamicOverflowAction",
    "CommandBarLabelPosition",
    "CommandBarOverflowButtonVisibility",
    "ContentDialogButton",
    "ContentDialogPlacement",
    "ContentDialogResult",
    "DisabledFormattingAccelerators",
    "ElementRealizationOptions",
    "ExpandDirection",
    "IncrementalLoadingTrigger",
    "IndexBasedLayoutOrientation",
    "InfoBarCloseReason",
    "InfoBarSeverity",
    "ItemCollectionTransitionOperation",
    "ItemCollectionTransitionTriggers",
    "ItemsUpdatingScrollMode",
    "ItemsViewSelectionMode",
    "LightDismissOverlayMode",
    "LinedFlowLayoutItemsJustification",
    "LinedFlowLayoutItemsStretch",
    "ListPickerFlyoutSelectionMode",
    "ListViewReorderMode",
    "ListViewSelectionMode",
    "NavigationViewBackButtonVisible",
    "NavigationViewDisplayMode",
    "NavigationViewOverflowLabelMode",
    "NavigationViewPaneDisplayMode",
    "NavigationViewSelectionFollowsFocus",
    "NavigationViewShoulderNavigationEnabled",
    "NumberBoxSpinButtonPlacementMode",
    "NumberBoxValidationMode",
    "Orientation",
    "PanelScrollingDirection",
    "ParallaxSourceOffsetKind",
    "PasswordRevealMode",
    "PipsPagerButtonVisibility",
    "PivotHeaderFocusVisualPlacement",
    "PivotSlideInAnimationGroup",
    "PlayerAnimationOptimization",
    "RefreshPullDirection",
    "RefreshVisualizerOrientation",
    "RefreshVisualizerState",
    "RequiresPointer",
    "RichEditClipboardFormat",
    "ScrollBarVisibility",
    "ScrollIntoViewAlignment",
    "ScrollMode",
    "ScrollingAnimationMode",
    "ScrollingChainMode",
    "ScrollingContentOrientation",
    "ScrollingInputKinds",
    "ScrollingInteractionState",
    "ScrollingRailMode",
    "ScrollingScrollBarVisibility",
    "ScrollingScrollMode",
    "ScrollingSnapPointsMode",
    "ScrollingZoomMode",
    "SelectionMode",
    "SnapPointsType",
    "SplitViewDisplayMode",
    "SplitViewPanePlacement",
    "StretchDirection",
    "SwipeBehaviorOnInvoked",
    "SwipeMode",
    "Symbol",
    "TabViewCloseButtonOverlayMode",
    "TabViewWidthMode",
    "TeachingTipCloseReason",
    "TeachingTipHeroContentPlacementMode",
    "TeachingTipPlacementMode",
    "TeachingTipTailVisibility",
    "TreeViewSelectionMode",
    "TwoPaneViewMode",
    "TwoPaneViewPriority",
    "TwoPaneViewTallModeConfiguration",
    "TwoPaneViewWideModeConfiguration",
    "UniformGridLayoutItemsJustification",
    "UniformGridLayoutItemsStretch",
    "VirtualizationMode",
    "ZoomMode",
    "AnchorRequestedEventArgs",
    "AnimatedIcon",
    "AnimatedIconSource",
    "AnimatedVisualPlayer",
    "AnnotatedScrollBar",
    "AnnotatedScrollBarDetailLabelRequestedEventArgs",
    "AnnotatedScrollBarLabel",
    "AnnotatedScrollBarScrollingEventArgs",
    "AppBar",
    "AppBarButton",
    "AppBarElementContainer",
    "AppBarSeparator",
    "AppBarToggleButton",
    "AutoSuggestBox",
    "AutoSuggestBoxQuerySubmittedEventArgs",
    "AutoSuggestBoxSuggestionChosenEventArgs",
    "AutoSuggestBoxTextChangedEventArgs",
    "BitmapIcon",
    "BitmapIconSource",
    "Border",
    "BreadcrumbBar",
    "BreadcrumbBarItem",
    "BreadcrumbBarItemClickedEventArgs",
    "Button",
    "CalendarDatePicker",
    "CalendarDatePickerDateChangedEventArgs",
    "CalendarView",
    "CalendarViewDayItem",
    "CalendarViewDayItemChangingEventArgs",
    "CalendarViewSelectedDatesChangedEventArgs",
    "CandidateWindowBoundsChangedEventArgs",
    "Canvas",
    "CheckBox",
    "ChoosingGroupHeaderContainerEventArgs",
    "ChoosingItemContainerEventArgs",
    "CleanUpVirtualizedItemEventArgs",
    "ColorChangedEventArgs",
    "ColorPicker",
    "ColumnDefinition",
    "ColumnDefinitionCollection",
    "ComboBox",
    "ComboBoxItem",
    "ComboBoxTextSubmittedEventArgs",
    "CommandBar",
    "CommandBarFlyout",
    "CommandBarOverflowPresenter",
    "ContainerContentChangingEventArgs",
    "ContentControl",
    "ContentDialog",
    "ContentDialogButtonClickDeferral",
    "ContentDialogButtonClickEventArgs",
    "ContentDialogClosedEventArgs",
    "ContentDialogClosingDeferral",
    "ContentDialogClosingEventArgs",
    "ContentDialogOpenedEventArgs",
    "ContentPresenter",
    "ContextMenuEventArgs",
    "Control",
    "ControlTemplate",
    "CoreWebView2InitializedEventArgs",
    "DataTemplateSelector",
    "DatePickedEventArgs",
    "DatePicker",
    "DatePickerFlyout",
    "DatePickerFlyoutItem",
    "DatePickerFlyoutPresenter",
    "DatePickerSelectedValueChangedEventArgs",
    "DatePickerValueChangedEventArgs",
    "DragItemsCompletedEventArgs",
    "DragItemsStartingEventArgs",
    "DropDownButton",
    "DynamicOverflowItemsChangingEventArgs",
    "Expander",
    "ExpanderCollapsedEventArgs",
    "ExpanderExpandingEventArgs",
    "ExpanderTemplateSettings",
    "FlipView",
    "FlipViewItem",
    "Flyout",
    "FlyoutPresenter",
    "FocusDisengagedEventArgs",
    "FocusEngagedEventArgs",
    "FontIcon",
    "FontIconSource",
    "Frame",
    "Grid",
    "GridView",
    "GridViewHeaderItem",
    "GridViewItem",
    "GroupItem",
    "GroupStyle",
    "GroupStyleSelector",
    "HasValidationErrorsChangedEventArgs",
    "Hub",
    "HubSection",
    "HubSectionCollection",
    "HubSectionHeaderClickEventArgs",
    "HyperlinkButton",
    "IconElement",
    "IconSource",
    "IconSourceElement",
    "Image",
    "ImageIcon",
    "ImageIconSource",
    "InfoBadge",
    "InfoBadgeTemplateSettings",
    "InfoBar",
    "InfoBarClosedEventArgs",
    "InfoBarClosingEventArgs",
    "InfoBarTemplateSettings",
    "IsTextTrimmedChangedEventArgs",
    "ItemClickEventArgs",
    "ItemCollection",
    "ItemCollectionTransition",
    "ItemCollectionTransitionCompletedEventArgs",
    "ItemCollectionTransitionProgress",
    "ItemCollectionTransitionProvider",
    "ItemContainer",
    "ItemContainerGenerator",
    "ItemsControl",
    "ItemsPanelTemplate",
    "ItemsPickedEventArgs",
    "ItemsPresenter",
    "ItemsRepeater",
    "ItemsRepeaterElementClearingEventArgs",
    "ItemsRepeaterElementIndexChangedEventArgs",
    "ItemsRepeaterElementPreparedEventArgs",
    "ItemsRepeaterScrollHost",
    "ItemsSourceView",
    "ItemsStackPanel",
    "ItemsView",
    "ItemsViewItemInvokedEventArgs",
    "ItemsViewSelectionChangedEventArgs",
    "ItemsWrapGrid",
    "Layout",
    "LayoutContext",
    "LinedFlowLayout",
    "LinedFlowLayoutItemCollectionTransitionProvider",
    "LinedFlowLayoutItemsInfoRequestedEventArgs",
    "ListBox",
    "ListBoxItem",
    "ListPickerFlyout",
    "ListPickerFlyoutPresenter",
    "ListView",
    "ListViewBase",
    "ListViewBaseHeaderItem",
    "ListViewHeaderItem",
    "ListViewItem",
    "ListViewPersistenceHelper",
    "MapControl",
    "MapControlMapServiceErrorOccurredEventArgs",
    "MapElement",
    "MapElementClickEventArgs",
    "MapElementsLayer",
    "MapIcon",
    "MapLayer",
    "MediaPlayerElement",
    "MediaPlayerPresenter",
    "MediaTransportControls",
    "MediaTransportControlsHelper",
    "MenuBar",
    "MenuBarItem",
    "MenuBarItemFlyout",
    "MenuFlyout",
    "MenuFlyoutItem",
    "MenuFlyoutItemBase",
    "MenuFlyoutPresenter",
    "MenuFlyoutSeparator",
    "MenuFlyoutSubItem",
    "NavigationView",
    "NavigationViewBackRequestedEventArgs",
    "NavigationViewDisplayModeChangedEventArgs",
    "NavigationViewItem",
    "NavigationViewItemBase",
    "NavigationViewItemCollapsedEventArgs",
    "NavigationViewItemExpandingEventArgs",
    "NavigationViewItemHeader",
    "NavigationViewItemInvokedEventArgs",
    "NavigationViewItemSeparator",
    "NavigationViewPaneClosingEventArgs",
    "NavigationViewSelectionChangedEventArgs",
    "NavigationViewTemplateSettings",
    "NonVirtualizingLayout",
    "NonVirtualizingLayoutContext",
    "NumberBox",
    "NumberBoxValueChangedEventArgs",
    "Page",
    "Panel",
    "ParallaxView",
    "PasswordBox",
    "PasswordBoxPasswordChangingEventArgs",
    "PathIcon",
    "PathIconSource",
    "PersonPicture",
    "PersonPictureTemplateSettings",
    "PickerConfirmedEventArgs",
    "PickerFlyout",
    "PickerFlyoutPresenter",
    "PipsPager",
    "PipsPagerSelectedIndexChangedEventArgs",
    "PipsPagerTemplateSettings",
    "Pivot",
    "PivotItem",
    "PivotItemEventArgs",
    "ProgressBar",
    "ProgressBarTemplateSettings",
    "ProgressRing",
    "ProgressRingTemplateSettings",
    "RadioButton",
    "RadioButtons",
    "RadioMenuFlyoutItem",
    "RatingControl",
    "RatingItemFontInfo",
    "RatingItemImageInfo",
    "RatingItemInfo",
    "RefreshContainer",
    "RefreshInteractionRatioChangedEventArgs",
    "RefreshRequestedEventArgs",
    "RefreshStateChangedEventArgs",
    "RefreshVisualizer",
    "RelativePanel",
    "RevealListViewItemPresenter",
    "RichEditBox",
    "RichEditBoxSelectionChangingEventArgs",
    "RichEditBoxTextChangingEventArgs",
    "RichTextBlock",
    "RichTextBlockOverflow",
    "RowDefinition",
    "RowDefinitionCollection",
    "ScrollContentPresenter",
    "ScrollView",
    "ScrollViewer",
    "ScrollViewerView",
    "ScrollViewerViewChangedEventArgs",
    "ScrollViewerViewChangingEventArgs",
    "ScrollingAnchorRequestedEventArgs",
    "ScrollingBringingIntoViewEventArgs",
    "ScrollingScrollAnimationStartingEventArgs",
    "ScrollingScrollCompletedEventArgs",
    "ScrollingScrollOptions",
    "ScrollingZoomAnimationStartingEventArgs",
    "ScrollingZoomCompletedEventArgs",
    "ScrollingZoomOptions",
    "SectionsInViewChangedEventArgs",
    "SelectionChangedEventArgs",
    "SelectorBar",
    "SelectorBarItem",
    "SelectorBarSelectionChangedEventArgs",
    "SemanticZoom",
    "SemanticZoomLocation",
    "SemanticZoomViewChangedEventArgs",
    "Slider",
    "SplitButton",
    "SplitButtonClickEventArgs",
    "SplitView",
    "SplitViewPaneClosingEventArgs",
    "StackLayout",
    "StackPanel",
    "StyleSelector",
    "SwapChainBackgroundPanel",
    "SwapChainPanel",
    "SwipeControl",
    "SwipeItem",
    "SwipeItemInvokedEventArgs",
    "SwipeItems",
    "SymbolIcon",
    "SymbolIconSource",
    "TabView",
    "TabViewItem",
    "TabViewItemTemplateSettings",
    "TabViewTabCloseRequestedEventArgs",
    "TabViewTabDragCompletedEventArgs",
    "TabViewTabDragStartingEventArgs",
    "TabViewTabDroppedOutsideEventArgs",
    "TeachingTip",
    "TeachingTipClosedEventArgs",
    "TeachingTipClosingEventArgs",
    "TeachingTipTemplateSettings",
    "TextBlock",
    "TextBox",
    "TextBoxBeforeTextChangingEventArgs",
    "TextBoxSelectionChangingEventArgs",
    "TextBoxTextChangingEventArgs",
    "TextChangedEventArgs",
    "TextCommandBarFlyout",
    "TextCompositionChangedEventArgs",
    "TextCompositionEndedEventArgs",
    "TextCompositionStartedEventArgs",
    "TextControlCopyingToClipboardEventArgs",
    "TextControlCuttingToClipboardEventArgs",
    "TextControlPasteEventArgs",
    "TimePickedEventArgs",
    "TimePicker",
    "TimePickerFlyout",
    "TimePickerFlyoutPresenter",
    "TimePickerSelectedValueChangedEventArgs",
    "TimePickerValueChangedEventArgs",
    "ToggleMenuFlyoutItem",
    "ToggleSplitButton",
    "ToggleSplitButtonIsCheckedChangedEventArgs",
    "ToggleSwitch",
    "ToolTip",
    "ToolTipService",
    "TreeView",
    "TreeViewCollapsedEventArgs",
    "TreeViewDragItemsCompletedEventArgs",
    "TreeViewDragItemsStartingEventArgs",
    "TreeViewExpandingEventArgs",
    "TreeViewItem",
    "TreeViewItemInvokedEventArgs",
    "TreeViewItemTemplateSettings",
    "TreeViewList",
    "TreeViewNode",
    "TreeViewSelectionChangedEventArgs",
    "TwoPaneView",
    "UIElementCollection",
    "UniformGridLayout",
    "UserControl",
    "VariableSizedWrapGrid",
    "Viewbox",
    "VirtualizingLayout",
    "VirtualizingLayoutContext",
    "VirtualizingPanel",
    "VirtualizingStackPanel",
    "WebView2",
    "WrapGrid",
    "XamlControlsResources",
    "IAnimatedVisual",
    "IAnimatedVisual2",
    "IAnimatedVisualSource",
    "IAnimatedVisualSource2",
    "IAnimatedVisualSource3",
    "ICommandBarElement",
    "IDynamicAnimatedVisualSource",
    "IInsertionPanel",
    "IItemContainerMapping",
    "IKeyIndexMapping",
    "INavigate",
    "IScrollAnchorProvider",
    "ISemanticZoomInformation",
    "CalendarViewDayItemChangingEventHandler",
    "CleanUpVirtualizedItemEventHandler",
    "ContextMenuOpeningEventHandler",
    "DragItemsStartingEventHandler",
    "HubSectionHeaderClickEventHandler",
    "ItemClickEventHandler",
    "ListViewItemToKeyHandler",
    "ListViewKeyToItemHandler",
    "SectionsInViewChangedEventHandler",
    "SelectionChangedEventHandler",
    "SemanticZoomViewChangedEventHandler",
    "TextChangedEventHandler",
    "TextControlPasteEventHandler",
]

class AnnotatedScrollBarScrollingEventKind(enum.IntEnum):
    CLICK = 0
    DRAG = 1
    INCREMENT_BUTTON = 2
    DECREMENT_BUTTON = 3

class AppBarClosedDisplayMode(enum.IntEnum):
    COMPACT = 0
    MINIMAL = 1
    HIDDEN = 2

class AutoSuggestionBoxTextChangeReason(enum.IntEnum):
    USER_INPUT = 0
    PROGRAMMATIC_CHANGE = 1
    SUGGESTION_CHOSEN = 2

class BackgroundSizing(enum.IntEnum):
    INNER_BORDER_EDGE = 0
    OUTER_BORDER_EDGE = 1

class CalendarViewDisplayMode(enum.IntEnum):
    MONTH = 0
    YEAR = 1
    DECADE = 2

class CalendarViewSelectionMode(enum.IntEnum):
    NONE = 0
    SINGLE = 1
    MULTIPLE = 2

class CandidateWindowAlignment(enum.IntEnum):
    DEFAULT = 0
    BOTTOM_EDGE = 1

class CharacterCasing(enum.IntEnum):
    NORMAL = 0
    LOWER = 1
    UPPER = 2

class ClickMode(enum.IntEnum):
    RELEASE = 0
    PRESS = 1
    HOVER = 2

class ColorPickerHsvChannel(enum.IntEnum):
    HUE = 0
    SATURATION = 1
    VALUE = 2
    ALPHA = 3

class ColorSpectrumComponents(enum.IntEnum):
    HUE_VALUE = 0
    VALUE_HUE = 1
    HUE_SATURATION = 2
    SATURATION_HUE = 3
    SATURATION_VALUE = 4
    VALUE_SATURATION = 5

class ColorSpectrumShape(enum.IntEnum):
    BOX = 0
    RING = 1

class ComboBoxSelectionChangedTrigger(enum.IntEnum):
    COMMITTED = 0
    ALWAYS = 1

class CommandBarDefaultLabelPosition(enum.IntEnum):
    BOTTOM = 0
    RIGHT = 1
    COLLAPSED = 2

class CommandBarDynamicOverflowAction(enum.IntEnum):
    ADDING_TO_OVERFLOW = 0
    REMOVING_FROM_OVERFLOW = 1

class CommandBarLabelPosition(enum.IntEnum):
    DEFAULT = 0
    COLLAPSED = 1

class CommandBarOverflowButtonVisibility(enum.IntEnum):
    AUTO = 0
    VISIBLE = 1
    COLLAPSED = 2

class ContentDialogButton(enum.IntEnum):
    NONE = 0
    PRIMARY = 1
    SECONDARY = 2
    CLOSE = 3

class ContentDialogPlacement(enum.IntEnum):
    POPUP = 0
    IN_PLACE = 1

class ContentDialogResult(enum.IntEnum):
    NONE = 0
    PRIMARY = 1
    SECONDARY = 2

class DisabledFormattingAccelerators(enum.IntFlag):
    NONE = 0x0
    BOLD = 0x1
    ITALIC = 0x2
    UNDERLINE = 0x4
    ALL = 0xFFFFFFFF

class ElementRealizationOptions(enum.IntFlag):
    NONE = 0x0
    FORCE_CREATE = 0x1
    SUPPRESS_AUTO_RECYCLE = 0x2

class ExpandDirection(enum.IntEnum):
    DOWN = 0
    UP = 1

class IncrementalLoadingTrigger(enum.IntEnum):
    NONE = 0
    EDGE = 1

class IndexBasedLayoutOrientation(enum.IntEnum):
    NONE = 0
    TOP_TO_BOTTOM = 1
    LEFT_TO_RIGHT = 2

class InfoBarCloseReason(enum.IntEnum):
    CLOSE_BUTTON = 0
    PROGRAMMATIC = 1

class InfoBarSeverity(enum.IntEnum):
    INFORMATIONAL = 0
    SUCCESS = 1
    WARNING = 2
    ERROR = 3

class ItemCollectionTransitionOperation(enum.IntEnum):
    ADD = 0
    REMOVE = 1
    MOVE = 2

class ItemCollectionTransitionTriggers(enum.IntFlag):
    COLLECTION_CHANGE_ADD = 0x1
    COLLECTION_CHANGE_REMOVE = 0x2
    COLLECTION_CHANGE_RESET = 0x4
    LAYOUT_TRANSITION = 0x8

class ItemsUpdatingScrollMode(enum.IntEnum):
    KEEP_ITEMS_IN_VIEW = 0
    KEEP_SCROLL_OFFSET = 1
    KEEP_LAST_ITEM_IN_VIEW = 2

class ItemsViewSelectionMode(enum.IntEnum):
    NONE = 0
    SINGLE = 1
    MULTIPLE = 2
    EXTENDED = 3

class LightDismissOverlayMode(enum.IntEnum):
    AUTO = 0
    ON = 1
    OFF = 2

class LinedFlowLayoutItemsJustification(enum.IntEnum):
    START = 0
    CENTER = 1
    END = 2
    SPACE_AROUND = 3
    SPACE_BETWEEN = 4
    SPACE_EVENLY = 5

class LinedFlowLayoutItemsStretch(enum.IntEnum):
    NONE = 0
    FILL = 1

class ListPickerFlyoutSelectionMode(enum.IntEnum):
    SINGLE = 0
    MULTIPLE = 1

class ListViewReorderMode(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1

class ListViewSelectionMode(enum.IntEnum):
    NONE = 0
    SINGLE = 1
    MULTIPLE = 2
    EXTENDED = 3

class NavigationViewBackButtonVisible(enum.IntEnum):
    COLLAPSED = 0
    VISIBLE = 1
    AUTO = 2

class NavigationViewDisplayMode(enum.IntEnum):
    MINIMAL = 0
    COMPACT = 1
    EXPANDED = 2

class NavigationViewOverflowLabelMode(enum.IntEnum):
    MORE_LABEL = 0
    NO_LABEL = 1

class NavigationViewPaneDisplayMode(enum.IntEnum):
    AUTO = 0
    LEFT = 1
    TOP = 2
    LEFT_COMPACT = 3
    LEFT_MINIMAL = 4

class NavigationViewSelectionFollowsFocus(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1

class NavigationViewShoulderNavigationEnabled(enum.IntEnum):
    WHEN_SELECTION_FOLLOWS_FOCUS = 0
    ALWAYS = 1
    NEVER = 2

class NumberBoxSpinButtonPlacementMode(enum.IntEnum):
    HIDDEN = 0
    COMPACT = 1
    INLINE = 2

class NumberBoxValidationMode(enum.IntEnum):
    INVALID_INPUT_OVERWRITTEN = 0
    DISABLED = 1

class Orientation(enum.IntEnum):
    VERTICAL = 0
    HORIZONTAL = 1

class PanelScrollingDirection(enum.IntEnum):
    NONE = 0
    FORWARD = 1
    BACKWARD = 2

class ParallaxSourceOffsetKind(enum.IntEnum):
    ABSOLUTE = 0
    RELATIVE = 1

class PasswordRevealMode(enum.IntEnum):
    PEEK = 0
    HIDDEN = 1
    VISIBLE = 2

class PipsPagerButtonVisibility(enum.IntEnum):
    VISIBLE = 0
    VISIBLE_ON_POINTER_OVER = 1
    COLLAPSED = 2

class PivotHeaderFocusVisualPlacement(enum.IntEnum):
    ITEM_HEADERS = 0
    SELECTED_ITEM_HEADER = 1

class PivotSlideInAnimationGroup(enum.IntEnum):
    DEFAULT = 0
    GROUP_ONE = 1
    GROUP_TWO = 2
    GROUP_THREE = 3

class PlayerAnimationOptimization(enum.IntEnum):
    LATENCY = 0
    RESOURCES = 1

class RefreshPullDirection(enum.IntEnum):
    LEFT_TO_RIGHT = 0
    TOP_TO_BOTTOM = 1
    RIGHT_TO_LEFT = 2
    BOTTOM_TO_TOP = 3

class RefreshVisualizerOrientation(enum.IntEnum):
    AUTO = 0
    NORMAL = 1
    ROTATE90_DEGREES_COUNTERCLOCKWISE = 2
    ROTATE270_DEGREES_COUNTERCLOCKWISE = 3

class RefreshVisualizerState(enum.IntEnum):
    IDLE = 0
    PEEKING = 1
    INTERACTING = 2
    PENDING = 3
    REFRESHING = 4

class RequiresPointer(enum.IntEnum):
    NEVER = 0
    WHEN_ENGAGED = 1
    WHEN_FOCUSED = 2

class RichEditClipboardFormat(enum.IntEnum):
    ALL_FORMATS = 0
    PLAIN_TEXT = 1

class ScrollBarVisibility(enum.IntEnum):
    DISABLED = 0
    AUTO = 1
    HIDDEN = 2
    VISIBLE = 3

class ScrollIntoViewAlignment(enum.IntEnum):
    DEFAULT = 0
    LEADING = 1

class ScrollMode(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1
    AUTO = 2

class ScrollingAnimationMode(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1
    AUTO = 2

class ScrollingChainMode(enum.IntEnum):
    AUTO = 0
    ALWAYS = 1
    NEVER = 2

class ScrollingContentOrientation(enum.IntEnum):
    VERTICAL = 0
    HORIZONTAL = 1
    NONE = 2
    BOTH = 3

class ScrollingInputKinds(enum.IntFlag):
    NONE = 0x0
    TOUCH = 0x1
    PEN = 0x2
    MOUSE_WHEEL = 0x4
    KEYBOARD = 0x8
    GAMEPAD = 0x10
    ALL = 0xFF

class ScrollingInteractionState(enum.IntEnum):
    IDLE = 0
    INTERACTION = 1
    INERTIA = 2
    ANIMATION = 3

class ScrollingRailMode(enum.IntEnum):
    ENABLED = 0
    DISABLED = 1

class ScrollingScrollBarVisibility(enum.IntEnum):
    AUTO = 0
    VISIBLE = 1
    HIDDEN = 2

class ScrollingScrollMode(enum.IntEnum):
    ENABLED = 0
    DISABLED = 1
    AUTO = 2

class ScrollingSnapPointsMode(enum.IntEnum):
    DEFAULT = 0
    IGNORE = 1

class ScrollingZoomMode(enum.IntEnum):
    ENABLED = 0
    DISABLED = 1

class SelectionMode(enum.IntEnum):
    SINGLE = 0
    MULTIPLE = 1
    EXTENDED = 2

class SnapPointsType(enum.IntEnum):
    NONE = 0
    OPTIONAL = 1
    MANDATORY = 2
    OPTIONAL_SINGLE = 3
    MANDATORY_SINGLE = 4

class SplitViewDisplayMode(enum.IntEnum):
    OVERLAY = 0
    INLINE = 1
    COMPACT_OVERLAY = 2
    COMPACT_INLINE = 3

class SplitViewPanePlacement(enum.IntEnum):
    LEFT = 0
    RIGHT = 1

class StretchDirection(enum.IntEnum):
    UP_ONLY = 0
    DOWN_ONLY = 1
    BOTH = 2

class SwipeBehaviorOnInvoked(enum.IntEnum):
    AUTO = 0
    CLOSE = 1
    REMAIN_OPEN = 2

class SwipeMode(enum.IntEnum):
    REVEAL = 0
    EXECUTE = 1

class Symbol(enum.IntEnum):
    PREVIOUS = 57600
    NEXT = 57601
    PLAY = 57602
    PAUSE = 57603
    EDIT = 57604
    SAVE = 57605
    CLEAR = 57606
    DELETE = 57607
    REMOVE = 57608
    ADD = 57609
    CANCEL = 57610
    ACCEPT = 57611
    MORE = 57612
    REDO = 57613
    UNDO = 57614
    HOME = 57615
    UP = 57616
    FORWARD = 57617
    BACK = 57618
    FAVORITE = 57619
    CAMERA = 57620
    SETTING = 57621
    VIDEO = 57622
    SYNC = 57623
    DOWNLOAD = 57624
    MAIL = 57625
    FIND = 57626
    HELP = 57627
    UPLOAD = 57628
    EMOJI = 57629
    TWO_PAGE = 57630
    LEAVE_CHAT = 57631
    MAIL_FORWARD = 57632
    CLOCK = 57633
    SEND = 57634
    CROP = 57635
    ROTATE_CAMERA = 57636
    PEOPLE = 57637
    OPEN_PANE = 57638
    CLOSE_PANE = 57639
    WORLD = 57640
    FLAG = 57641
    PREVIEW_LINK = 57642
    GLOBE = 57643
    TRIM = 57644
    ATTACH_CAMERA = 57645
    ZOOM_IN = 57646
    BOOKMARKS = 57647
    DOCUMENT = 57648
    PROTECTED_DOCUMENT = 57649
    PAGE = 57650
    BULLETS = 57651
    COMMENT = 57652
    MAIL_FILLED = 57653
    CONTACT_INFO = 57654
    HANG_UP = 57655
    VIEW_ALL = 57656
    MAP_PIN = 57657
    PHONE = 57658
    VIDEO_CHAT = 57659
    SWITCH = 57660
    CONTACT = 57661
    RENAME = 57662
    PIN = 57665
    MUSIC_INFO = 57666
    GO = 57667
    KEYBOARD = 57668
    DOCK_LEFT = 57669
    DOCK_RIGHT = 57670
    DOCK_BOTTOM = 57671
    REMOTE = 57672
    REFRESH = 57673
    ROTATE = 57674
    SHUFFLE = 57675
    LIST = 57676
    SHOP = 57677
    SELECT_ALL = 57678
    ORIENTATION = 57679
    IMPORT = 57680
    IMPORT_ALL = 57681
    BROWSE_PHOTOS = 57685
    WEB_CAM = 57686
    PICTURES = 57688
    SAVE_LOCAL = 57689
    CAPTION = 57690
    STOP = 57691
    SHOW_RESULTS = 57692
    VOLUME = 57693
    REPAIR = 57694
    MESSAGE = 57695
    PAGE2 = 57696
    CALENDAR_DAY = 57697
    CALENDAR_WEEK = 57698
    CALENDAR = 57699
    CHARACTER = 57700
    MAIL_REPLY_ALL = 57701
    READ = 57702
    LINK = 57703
    ACCOUNT = 57704
    SHOW_BCC = 57705
    HIDE_BCC = 57706
    CUT = 57707
    ATTACH = 57708
    PASTE = 57709
    FILTER = 57710
    COPY = 57711
    EMOJI2 = 57712
    IMPORTANT = 57713
    MAIL_REPLY = 57714
    SLIDE_SHOW = 57715
    SORT = 57716
    MANAGE = 57720
    ALL_APPS = 57721
    DISCONNECT_DRIVE = 57722
    MAP_DRIVE = 57723
    NEW_WINDOW = 57724
    OPEN_WITH = 57725
    CONTACT_PRESENCE = 57729
    PRIORITY = 57730
    GO_TO_TODAY = 57732
    FONT = 57733
    FONT_COLOR = 57734
    CONTACT2 = 57735
    FOLDER = 57736
    AUDIO = 57737
    PLACEHOLDER = 57738
    VIEW = 57739
    SET_LOCK_SCREEN = 57740
    SET_TILE = 57741
    CLOSED_CAPTION = 57744
    STOP_SLIDE_SHOW = 57745
    PERMISSIONS = 57746
    HIGHLIGHT = 57747
    DISABLE_UPDATES = 57748
    UN_FAVORITE = 57749
    UN_PIN = 57750
    OPEN_LOCAL = 57751
    MUTE = 57752
    ITALIC = 57753
    UNDERLINE = 57754
    BOLD = 57755
    MOVE_TO_FOLDER = 57756
    LIKE_DISLIKE = 57757
    DISLIKE = 57758
    LIKE = 57759
    ALIGN_RIGHT = 57760
    ALIGN_CENTER = 57761
    ALIGN_LEFT = 57762
    ZOOM = 57763
    ZOOM_OUT = 57764
    OPEN_FILE = 57765
    OTHER_USER = 57766
    ADMIN = 57767
    STREET = 57795
    MAP = 57796
    CLEAR_SELECTION = 57797
    FONT_DECREASE = 57798
    FONT_INCREASE = 57799
    FONT_SIZE = 57800
    CELL_PHONE = 57801
    RE_SHARE = 57802
    TAG = 57803
    REPEAT_ONE = 57804
    REPEAT_ALL = 57805
    OUTLINE_STAR = 57806
    SOLID_STAR = 57807
    CALCULATOR = 57808
    DIRECTIONS = 57809
    TARGET = 57810
    LIBRARY = 57811
    PHONE_BOOK = 57812
    MEMO = 57813
    MICROPHONE = 57814
    POST_UPDATE = 57815
    BACK_TO_WINDOW = 57816
    FULL_SCREEN = 57817
    NEW_FOLDER = 57818
    CALENDAR_REPLY = 57819
    UN_SYNC_FOLDER = 57821
    REPORT_HACKED = 57822
    SYNC_FOLDER = 57823
    BLOCK_CONTACT = 57824
    SWITCH_APPS = 57825
    ADD_FRIEND = 57826
    TOUCH_POINTER = 57827
    GO_TO_START = 57828
    ZERO_BARS = 57829
    ONE_BAR = 57830
    TWO_BARS = 57831
    THREE_BARS = 57832
    FOUR_BARS = 57833
    SCAN = 58004
    PREVIEW = 58005
    GLOBAL_NAVIGATION_BUTTON = 59136
    SHARE = 59181
    PRINT = 59209
    XBOX_ONE_CONSOLE = 59792

class TabViewCloseButtonOverlayMode(enum.IntEnum):
    AUTO = 0
    ON_POINTER_OVER = 1
    ALWAYS = 2

class TabViewWidthMode(enum.IntEnum):
    EQUAL = 0
    SIZE_TO_CONTENT = 1
    COMPACT = 2

class TeachingTipCloseReason(enum.IntEnum):
    CLOSE_BUTTON = 0
    LIGHT_DISMISS = 1
    PROGRAMMATIC = 2

class TeachingTipHeroContentPlacementMode(enum.IntEnum):
    AUTO = 0
    TOP = 1
    BOTTOM = 2

class TeachingTipPlacementMode(enum.IntEnum):
    AUTO = 0
    TOP = 1
    BOTTOM = 2
    LEFT = 3
    RIGHT = 4
    TOP_RIGHT = 5
    TOP_LEFT = 6
    BOTTOM_RIGHT = 7
    BOTTOM_LEFT = 8
    LEFT_TOP = 9
    LEFT_BOTTOM = 10
    RIGHT_TOP = 11
    RIGHT_BOTTOM = 12
    CENTER = 13

class TeachingTipTailVisibility(enum.IntEnum):
    AUTO = 0
    VISIBLE = 1
    COLLAPSED = 2

class TreeViewSelectionMode(enum.IntEnum):
    NONE = 0
    SINGLE = 1
    MULTIPLE = 2

class TwoPaneViewMode(enum.IntEnum):
    SINGLE_PANE = 0
    WIDE = 1
    TALL = 2

class TwoPaneViewPriority(enum.IntEnum):
    PANE1 = 0
    PANE2 = 1

class TwoPaneViewTallModeConfiguration(enum.IntEnum):
    SINGLE_PANE = 0
    TOP_BOTTOM = 1
    BOTTOM_TOP = 2

class TwoPaneViewWideModeConfiguration(enum.IntEnum):
    SINGLE_PANE = 0
    LEFT_RIGHT = 1
    RIGHT_LEFT = 2

class UniformGridLayoutItemsJustification(enum.IntEnum):
    START = 0
    CENTER = 1
    END = 2
    SPACE_AROUND = 3
    SPACE_BETWEEN = 4
    SPACE_EVENLY = 5

class UniformGridLayoutItemsStretch(enum.IntEnum):
    NONE = 0
    FILL = 1
    UNIFORM = 2

class VirtualizationMode(enum.IntEnum):
    STANDARD = 0
    RECYCLING = 1

class ZoomMode(enum.IntEnum):
    DISABLED = 0
    ENABLED = 1

AnchorRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.AnchorRequestedEventArgs
AnimatedIcon = _winrt_microsoft_ui_xaml_controls.AnimatedIcon
AnimatedIconSource = _winrt_microsoft_ui_xaml_controls.AnimatedIconSource
AnimatedVisualPlayer = _winrt_microsoft_ui_xaml_controls.AnimatedVisualPlayer
AnnotatedScrollBar = _winrt_microsoft_ui_xaml_controls.AnnotatedScrollBar
AnnotatedScrollBarDetailLabelRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.AnnotatedScrollBarDetailLabelRequestedEventArgs
AnnotatedScrollBarLabel = _winrt_microsoft_ui_xaml_controls.AnnotatedScrollBarLabel
AnnotatedScrollBarScrollingEventArgs = _winrt_microsoft_ui_xaml_controls.AnnotatedScrollBarScrollingEventArgs
AppBar = _winrt_microsoft_ui_xaml_controls.AppBar
AppBarButton = _winrt_microsoft_ui_xaml_controls.AppBarButton
AppBarElementContainer = _winrt_microsoft_ui_xaml_controls.AppBarElementContainer
AppBarSeparator = _winrt_microsoft_ui_xaml_controls.AppBarSeparator
AppBarToggleButton = _winrt_microsoft_ui_xaml_controls.AppBarToggleButton
AutoSuggestBox = _winrt_microsoft_ui_xaml_controls.AutoSuggestBox
AutoSuggestBoxQuerySubmittedEventArgs = _winrt_microsoft_ui_xaml_controls.AutoSuggestBoxQuerySubmittedEventArgs
AutoSuggestBoxSuggestionChosenEventArgs = _winrt_microsoft_ui_xaml_controls.AutoSuggestBoxSuggestionChosenEventArgs
AutoSuggestBoxTextChangedEventArgs = _winrt_microsoft_ui_xaml_controls.AutoSuggestBoxTextChangedEventArgs
BitmapIcon = _winrt_microsoft_ui_xaml_controls.BitmapIcon
BitmapIconSource = _winrt_microsoft_ui_xaml_controls.BitmapIconSource
Border = _winrt_microsoft_ui_xaml_controls.Border
BreadcrumbBar = _winrt_microsoft_ui_xaml_controls.BreadcrumbBar
BreadcrumbBarItem = _winrt_microsoft_ui_xaml_controls.BreadcrumbBarItem
BreadcrumbBarItemClickedEventArgs = _winrt_microsoft_ui_xaml_controls.BreadcrumbBarItemClickedEventArgs
Button = _winrt_microsoft_ui_xaml_controls.Button
CalendarDatePicker = _winrt_microsoft_ui_xaml_controls.CalendarDatePicker
CalendarDatePickerDateChangedEventArgs = _winrt_microsoft_ui_xaml_controls.CalendarDatePickerDateChangedEventArgs
CalendarView = _winrt_microsoft_ui_xaml_controls.CalendarView
CalendarViewDayItem = _winrt_microsoft_ui_xaml_controls.CalendarViewDayItem
CalendarViewDayItemChangingEventArgs = _winrt_microsoft_ui_xaml_controls.CalendarViewDayItemChangingEventArgs
CalendarViewSelectedDatesChangedEventArgs = _winrt_microsoft_ui_xaml_controls.CalendarViewSelectedDatesChangedEventArgs
CandidateWindowBoundsChangedEventArgs = _winrt_microsoft_ui_xaml_controls.CandidateWindowBoundsChangedEventArgs
Canvas = _winrt_microsoft_ui_xaml_controls.Canvas
CheckBox = _winrt_microsoft_ui_xaml_controls.CheckBox
ChoosingGroupHeaderContainerEventArgs = _winrt_microsoft_ui_xaml_controls.ChoosingGroupHeaderContainerEventArgs
ChoosingItemContainerEventArgs = _winrt_microsoft_ui_xaml_controls.ChoosingItemContainerEventArgs
CleanUpVirtualizedItemEventArgs = _winrt_microsoft_ui_xaml_controls.CleanUpVirtualizedItemEventArgs
ColorChangedEventArgs = _winrt_microsoft_ui_xaml_controls.ColorChangedEventArgs
ColorPicker = _winrt_microsoft_ui_xaml_controls.ColorPicker
ColumnDefinition = _winrt_microsoft_ui_xaml_controls.ColumnDefinition
ColumnDefinitionCollection = _winrt_microsoft_ui_xaml_controls.ColumnDefinitionCollection
winrt.system._mixin_mutable_sequence(ColumnDefinitionCollection)
ComboBox = _winrt_microsoft_ui_xaml_controls.ComboBox
ComboBoxItem = _winrt_microsoft_ui_xaml_controls.ComboBoxItem
ComboBoxTextSubmittedEventArgs = _winrt_microsoft_ui_xaml_controls.ComboBoxTextSubmittedEventArgs
CommandBar = _winrt_microsoft_ui_xaml_controls.CommandBar
CommandBarFlyout = _winrt_microsoft_ui_xaml_controls.CommandBarFlyout
CommandBarOverflowPresenter = _winrt_microsoft_ui_xaml_controls.CommandBarOverflowPresenter
ContainerContentChangingEventArgs = _winrt_microsoft_ui_xaml_controls.ContainerContentChangingEventArgs
ContentControl = _winrt_microsoft_ui_xaml_controls.ContentControl
ContentDialog = _winrt_microsoft_ui_xaml_controls.ContentDialog
ContentDialogButtonClickDeferral = _winrt_microsoft_ui_xaml_controls.ContentDialogButtonClickDeferral
ContentDialogButtonClickEventArgs = _winrt_microsoft_ui_xaml_controls.ContentDialogButtonClickEventArgs
ContentDialogClosedEventArgs = _winrt_microsoft_ui_xaml_controls.ContentDialogClosedEventArgs
ContentDialogClosingDeferral = _winrt_microsoft_ui_xaml_controls.ContentDialogClosingDeferral
ContentDialogClosingEventArgs = _winrt_microsoft_ui_xaml_controls.ContentDialogClosingEventArgs
ContentDialogOpenedEventArgs = _winrt_microsoft_ui_xaml_controls.ContentDialogOpenedEventArgs
ContentPresenter = _winrt_microsoft_ui_xaml_controls.ContentPresenter
ContextMenuEventArgs = _winrt_microsoft_ui_xaml_controls.ContextMenuEventArgs
Control = _winrt_microsoft_ui_xaml_controls.Control
ControlTemplate = _winrt_microsoft_ui_xaml_controls.ControlTemplate
CoreWebView2InitializedEventArgs = _winrt_microsoft_ui_xaml_controls.CoreWebView2InitializedEventArgs
DataTemplateSelector = _winrt_microsoft_ui_xaml_controls.DataTemplateSelector
DatePickedEventArgs = _winrt_microsoft_ui_xaml_controls.DatePickedEventArgs
DatePicker = _winrt_microsoft_ui_xaml_controls.DatePicker
DatePickerFlyout = _winrt_microsoft_ui_xaml_controls.DatePickerFlyout
DatePickerFlyoutItem = _winrt_microsoft_ui_xaml_controls.DatePickerFlyoutItem
DatePickerFlyoutPresenter = _winrt_microsoft_ui_xaml_controls.DatePickerFlyoutPresenter
DatePickerSelectedValueChangedEventArgs = _winrt_microsoft_ui_xaml_controls.DatePickerSelectedValueChangedEventArgs
DatePickerValueChangedEventArgs = _winrt_microsoft_ui_xaml_controls.DatePickerValueChangedEventArgs
DragItemsCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.DragItemsCompletedEventArgs
DragItemsStartingEventArgs = _winrt_microsoft_ui_xaml_controls.DragItemsStartingEventArgs
DropDownButton = _winrt_microsoft_ui_xaml_controls.DropDownButton
DynamicOverflowItemsChangingEventArgs = _winrt_microsoft_ui_xaml_controls.DynamicOverflowItemsChangingEventArgs
Expander = _winrt_microsoft_ui_xaml_controls.Expander
ExpanderCollapsedEventArgs = _winrt_microsoft_ui_xaml_controls.ExpanderCollapsedEventArgs
ExpanderExpandingEventArgs = _winrt_microsoft_ui_xaml_controls.ExpanderExpandingEventArgs
ExpanderTemplateSettings = _winrt_microsoft_ui_xaml_controls.ExpanderTemplateSettings
FlipView = _winrt_microsoft_ui_xaml_controls.FlipView
FlipViewItem = _winrt_microsoft_ui_xaml_controls.FlipViewItem
Flyout = _winrt_microsoft_ui_xaml_controls.Flyout
FlyoutPresenter = _winrt_microsoft_ui_xaml_controls.FlyoutPresenter
FocusDisengagedEventArgs = _winrt_microsoft_ui_xaml_controls.FocusDisengagedEventArgs
FocusEngagedEventArgs = _winrt_microsoft_ui_xaml_controls.FocusEngagedEventArgs
FontIcon = _winrt_microsoft_ui_xaml_controls.FontIcon
FontIconSource = _winrt_microsoft_ui_xaml_controls.FontIconSource
Frame = _winrt_microsoft_ui_xaml_controls.Frame
Grid = _winrt_microsoft_ui_xaml_controls.Grid
GridView = _winrt_microsoft_ui_xaml_controls.GridView
GridViewHeaderItem = _winrt_microsoft_ui_xaml_controls.GridViewHeaderItem
GridViewItem = _winrt_microsoft_ui_xaml_controls.GridViewItem
GroupItem = _winrt_microsoft_ui_xaml_controls.GroupItem
GroupStyle = _winrt_microsoft_ui_xaml_controls.GroupStyle
GroupStyleSelector = _winrt_microsoft_ui_xaml_controls.GroupStyleSelector
HasValidationErrorsChangedEventArgs = _winrt_microsoft_ui_xaml_controls.HasValidationErrorsChangedEventArgs
Hub = _winrt_microsoft_ui_xaml_controls.Hub
HubSection = _winrt_microsoft_ui_xaml_controls.HubSection
HubSectionCollection = _winrt_microsoft_ui_xaml_controls.HubSectionCollection
winrt.system._mixin_mutable_sequence(HubSectionCollection)
HubSectionHeaderClickEventArgs = _winrt_microsoft_ui_xaml_controls.HubSectionHeaderClickEventArgs
HyperlinkButton = _winrt_microsoft_ui_xaml_controls.HyperlinkButton
IconElement = _winrt_microsoft_ui_xaml_controls.IconElement
IconSource = _winrt_microsoft_ui_xaml_controls.IconSource
IconSourceElement = _winrt_microsoft_ui_xaml_controls.IconSourceElement
Image = _winrt_microsoft_ui_xaml_controls.Image
ImageIcon = _winrt_microsoft_ui_xaml_controls.ImageIcon
ImageIconSource = _winrt_microsoft_ui_xaml_controls.ImageIconSource
InfoBadge = _winrt_microsoft_ui_xaml_controls.InfoBadge
InfoBadgeTemplateSettings = _winrt_microsoft_ui_xaml_controls.InfoBadgeTemplateSettings
InfoBar = _winrt_microsoft_ui_xaml_controls.InfoBar
InfoBarClosedEventArgs = _winrt_microsoft_ui_xaml_controls.InfoBarClosedEventArgs
InfoBarClosingEventArgs = _winrt_microsoft_ui_xaml_controls.InfoBarClosingEventArgs
InfoBarTemplateSettings = _winrt_microsoft_ui_xaml_controls.InfoBarTemplateSettings
IsTextTrimmedChangedEventArgs = _winrt_microsoft_ui_xaml_controls.IsTextTrimmedChangedEventArgs
ItemClickEventArgs = _winrt_microsoft_ui_xaml_controls.ItemClickEventArgs
ItemCollection = _winrt_microsoft_ui_xaml_controls.ItemCollection
winrt.system._mixin_mutable_sequence(ItemCollection)
ItemCollectionTransition = _winrt_microsoft_ui_xaml_controls.ItemCollectionTransition
ItemCollectionTransitionCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemCollectionTransitionCompletedEventArgs
ItemCollectionTransitionProgress = _winrt_microsoft_ui_xaml_controls.ItemCollectionTransitionProgress
ItemCollectionTransitionProvider = _winrt_microsoft_ui_xaml_controls.ItemCollectionTransitionProvider
ItemContainer = _winrt_microsoft_ui_xaml_controls.ItemContainer
ItemContainerGenerator = _winrt_microsoft_ui_xaml_controls.ItemContainerGenerator
ItemsControl = _winrt_microsoft_ui_xaml_controls.ItemsControl
ItemsPanelTemplate = _winrt_microsoft_ui_xaml_controls.ItemsPanelTemplate
ItemsPickedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsPickedEventArgs
ItemsPresenter = _winrt_microsoft_ui_xaml_controls.ItemsPresenter
ItemsRepeater = _winrt_microsoft_ui_xaml_controls.ItemsRepeater
ItemsRepeaterElementClearingEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsRepeaterElementClearingEventArgs
ItemsRepeaterElementIndexChangedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsRepeaterElementIndexChangedEventArgs
ItemsRepeaterElementPreparedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsRepeaterElementPreparedEventArgs
ItemsRepeaterScrollHost = _winrt_microsoft_ui_xaml_controls.ItemsRepeaterScrollHost
ItemsSourceView = _winrt_microsoft_ui_xaml_controls.ItemsSourceView
ItemsStackPanel = _winrt_microsoft_ui_xaml_controls.ItemsStackPanel
ItemsView = _winrt_microsoft_ui_xaml_controls.ItemsView
ItemsViewItemInvokedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsViewItemInvokedEventArgs
ItemsViewSelectionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.ItemsViewSelectionChangedEventArgs
ItemsWrapGrid = _winrt_microsoft_ui_xaml_controls.ItemsWrapGrid
Layout = _winrt_microsoft_ui_xaml_controls.Layout
LayoutContext = _winrt_microsoft_ui_xaml_controls.LayoutContext
LinedFlowLayout = _winrt_microsoft_ui_xaml_controls.LinedFlowLayout
LinedFlowLayoutItemCollectionTransitionProvider = _winrt_microsoft_ui_xaml_controls.LinedFlowLayoutItemCollectionTransitionProvider
LinedFlowLayoutItemsInfoRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.LinedFlowLayoutItemsInfoRequestedEventArgs
ListBox = _winrt_microsoft_ui_xaml_controls.ListBox
ListBoxItem = _winrt_microsoft_ui_xaml_controls.ListBoxItem
ListPickerFlyout = _winrt_microsoft_ui_xaml_controls.ListPickerFlyout
ListPickerFlyoutPresenter = _winrt_microsoft_ui_xaml_controls.ListPickerFlyoutPresenter
ListView = _winrt_microsoft_ui_xaml_controls.ListView
ListViewBase = _winrt_microsoft_ui_xaml_controls.ListViewBase
ListViewBaseHeaderItem = _winrt_microsoft_ui_xaml_controls.ListViewBaseHeaderItem
ListViewHeaderItem = _winrt_microsoft_ui_xaml_controls.ListViewHeaderItem
ListViewItem = _winrt_microsoft_ui_xaml_controls.ListViewItem
ListViewPersistenceHelper = _winrt_microsoft_ui_xaml_controls.ListViewPersistenceHelper
MapControl = _winrt_microsoft_ui_xaml_controls.MapControl
MapControlMapServiceErrorOccurredEventArgs = _winrt_microsoft_ui_xaml_controls.MapControlMapServiceErrorOccurredEventArgs
MapElement = _winrt_microsoft_ui_xaml_controls.MapElement
MapElementClickEventArgs = _winrt_microsoft_ui_xaml_controls.MapElementClickEventArgs
MapElementsLayer = _winrt_microsoft_ui_xaml_controls.MapElementsLayer
MapIcon = _winrt_microsoft_ui_xaml_controls.MapIcon
MapLayer = _winrt_microsoft_ui_xaml_controls.MapLayer
MediaPlayerElement = _winrt_microsoft_ui_xaml_controls.MediaPlayerElement
MediaPlayerPresenter = _winrt_microsoft_ui_xaml_controls.MediaPlayerPresenter
MediaTransportControls = _winrt_microsoft_ui_xaml_controls.MediaTransportControls
MediaTransportControlsHelper = _winrt_microsoft_ui_xaml_controls.MediaTransportControlsHelper
MenuBar = _winrt_microsoft_ui_xaml_controls.MenuBar
MenuBarItem = _winrt_microsoft_ui_xaml_controls.MenuBarItem
MenuBarItemFlyout = _winrt_microsoft_ui_xaml_controls.MenuBarItemFlyout
MenuFlyout = _winrt_microsoft_ui_xaml_controls.MenuFlyout
MenuFlyoutItem = _winrt_microsoft_ui_xaml_controls.MenuFlyoutItem
MenuFlyoutItemBase = _winrt_microsoft_ui_xaml_controls.MenuFlyoutItemBase
MenuFlyoutPresenter = _winrt_microsoft_ui_xaml_controls.MenuFlyoutPresenter
MenuFlyoutSeparator = _winrt_microsoft_ui_xaml_controls.MenuFlyoutSeparator
MenuFlyoutSubItem = _winrt_microsoft_ui_xaml_controls.MenuFlyoutSubItem
NavigationView = _winrt_microsoft_ui_xaml_controls.NavigationView
NavigationViewBackRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewBackRequestedEventArgs
NavigationViewDisplayModeChangedEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewDisplayModeChangedEventArgs
NavigationViewItem = _winrt_microsoft_ui_xaml_controls.NavigationViewItem
NavigationViewItemBase = _winrt_microsoft_ui_xaml_controls.NavigationViewItemBase
NavigationViewItemCollapsedEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewItemCollapsedEventArgs
NavigationViewItemExpandingEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewItemExpandingEventArgs
NavigationViewItemHeader = _winrt_microsoft_ui_xaml_controls.NavigationViewItemHeader
NavigationViewItemInvokedEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewItemInvokedEventArgs
NavigationViewItemSeparator = _winrt_microsoft_ui_xaml_controls.NavigationViewItemSeparator
NavigationViewPaneClosingEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewPaneClosingEventArgs
NavigationViewSelectionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.NavigationViewSelectionChangedEventArgs
NavigationViewTemplateSettings = _winrt_microsoft_ui_xaml_controls.NavigationViewTemplateSettings
NonVirtualizingLayout = _winrt_microsoft_ui_xaml_controls.NonVirtualizingLayout
NonVirtualizingLayoutContext = _winrt_microsoft_ui_xaml_controls.NonVirtualizingLayoutContext
NumberBox = _winrt_microsoft_ui_xaml_controls.NumberBox
NumberBoxValueChangedEventArgs = _winrt_microsoft_ui_xaml_controls.NumberBoxValueChangedEventArgs
Page = _winrt_microsoft_ui_xaml_controls.Page
Panel = _winrt_microsoft_ui_xaml_controls.Panel
ParallaxView = _winrt_microsoft_ui_xaml_controls.ParallaxView
PasswordBox = _winrt_microsoft_ui_xaml_controls.PasswordBox
PasswordBoxPasswordChangingEventArgs = _winrt_microsoft_ui_xaml_controls.PasswordBoxPasswordChangingEventArgs
PathIcon = _winrt_microsoft_ui_xaml_controls.PathIcon
PathIconSource = _winrt_microsoft_ui_xaml_controls.PathIconSource
PersonPicture = _winrt_microsoft_ui_xaml_controls.PersonPicture
PersonPictureTemplateSettings = _winrt_microsoft_ui_xaml_controls.PersonPictureTemplateSettings
PickerConfirmedEventArgs = _winrt_microsoft_ui_xaml_controls.PickerConfirmedEventArgs
PickerFlyout = _winrt_microsoft_ui_xaml_controls.PickerFlyout
PickerFlyoutPresenter = _winrt_microsoft_ui_xaml_controls.PickerFlyoutPresenter
PipsPager = _winrt_microsoft_ui_xaml_controls.PipsPager
PipsPagerSelectedIndexChangedEventArgs = _winrt_microsoft_ui_xaml_controls.PipsPagerSelectedIndexChangedEventArgs
PipsPagerTemplateSettings = _winrt_microsoft_ui_xaml_controls.PipsPagerTemplateSettings
Pivot = _winrt_microsoft_ui_xaml_controls.Pivot
PivotItem = _winrt_microsoft_ui_xaml_controls.PivotItem
PivotItemEventArgs = _winrt_microsoft_ui_xaml_controls.PivotItemEventArgs
ProgressBar = _winrt_microsoft_ui_xaml_controls.ProgressBar
ProgressBarTemplateSettings = _winrt_microsoft_ui_xaml_controls.ProgressBarTemplateSettings
ProgressRing = _winrt_microsoft_ui_xaml_controls.ProgressRing
ProgressRingTemplateSettings = _winrt_microsoft_ui_xaml_controls.ProgressRingTemplateSettings
RadioButton = _winrt_microsoft_ui_xaml_controls.RadioButton
RadioButtons = _winrt_microsoft_ui_xaml_controls.RadioButtons
RadioMenuFlyoutItem = _winrt_microsoft_ui_xaml_controls.RadioMenuFlyoutItem
RatingControl = _winrt_microsoft_ui_xaml_controls.RatingControl
RatingItemFontInfo = _winrt_microsoft_ui_xaml_controls.RatingItemFontInfo
RatingItemImageInfo = _winrt_microsoft_ui_xaml_controls.RatingItemImageInfo
RatingItemInfo = _winrt_microsoft_ui_xaml_controls.RatingItemInfo
RefreshContainer = _winrt_microsoft_ui_xaml_controls.RefreshContainer
RefreshInteractionRatioChangedEventArgs = _winrt_microsoft_ui_xaml_controls.RefreshInteractionRatioChangedEventArgs
RefreshRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.RefreshRequestedEventArgs
RefreshStateChangedEventArgs = _winrt_microsoft_ui_xaml_controls.RefreshStateChangedEventArgs
RefreshVisualizer = _winrt_microsoft_ui_xaml_controls.RefreshVisualizer
RelativePanel = _winrt_microsoft_ui_xaml_controls.RelativePanel
RevealListViewItemPresenter = _winrt_microsoft_ui_xaml_controls.RevealListViewItemPresenter
RichEditBox = _winrt_microsoft_ui_xaml_controls.RichEditBox
RichEditBoxSelectionChangingEventArgs = _winrt_microsoft_ui_xaml_controls.RichEditBoxSelectionChangingEventArgs
RichEditBoxTextChangingEventArgs = _winrt_microsoft_ui_xaml_controls.RichEditBoxTextChangingEventArgs
RichTextBlock = _winrt_microsoft_ui_xaml_controls.RichTextBlock
RichTextBlockOverflow = _winrt_microsoft_ui_xaml_controls.RichTextBlockOverflow
RowDefinition = _winrt_microsoft_ui_xaml_controls.RowDefinition
RowDefinitionCollection = _winrt_microsoft_ui_xaml_controls.RowDefinitionCollection
winrt.system._mixin_mutable_sequence(RowDefinitionCollection)
ScrollContentPresenter = _winrt_microsoft_ui_xaml_controls.ScrollContentPresenter
ScrollView = _winrt_microsoft_ui_xaml_controls.ScrollView
ScrollViewer = _winrt_microsoft_ui_xaml_controls.ScrollViewer
ScrollViewerView = _winrt_microsoft_ui_xaml_controls.ScrollViewerView
ScrollViewerViewChangedEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollViewerViewChangedEventArgs
ScrollViewerViewChangingEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollViewerViewChangingEventArgs
ScrollingAnchorRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingAnchorRequestedEventArgs
ScrollingBringingIntoViewEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingBringingIntoViewEventArgs
ScrollingScrollAnimationStartingEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingScrollAnimationStartingEventArgs
ScrollingScrollCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingScrollCompletedEventArgs
ScrollingScrollOptions = _winrt_microsoft_ui_xaml_controls.ScrollingScrollOptions
ScrollingZoomAnimationStartingEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingZoomAnimationStartingEventArgs
ScrollingZoomCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.ScrollingZoomCompletedEventArgs
ScrollingZoomOptions = _winrt_microsoft_ui_xaml_controls.ScrollingZoomOptions
SectionsInViewChangedEventArgs = _winrt_microsoft_ui_xaml_controls.SectionsInViewChangedEventArgs
SelectionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.SelectionChangedEventArgs
SelectorBar = _winrt_microsoft_ui_xaml_controls.SelectorBar
SelectorBarItem = _winrt_microsoft_ui_xaml_controls.SelectorBarItem
SelectorBarSelectionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.SelectorBarSelectionChangedEventArgs
SemanticZoom = _winrt_microsoft_ui_xaml_controls.SemanticZoom
SemanticZoomLocation = _winrt_microsoft_ui_xaml_controls.SemanticZoomLocation
SemanticZoomViewChangedEventArgs = _winrt_microsoft_ui_xaml_controls.SemanticZoomViewChangedEventArgs
Slider = _winrt_microsoft_ui_xaml_controls.Slider
SplitButton = _winrt_microsoft_ui_xaml_controls.SplitButton
SplitButtonClickEventArgs = _winrt_microsoft_ui_xaml_controls.SplitButtonClickEventArgs
SplitView = _winrt_microsoft_ui_xaml_controls.SplitView
SplitViewPaneClosingEventArgs = _winrt_microsoft_ui_xaml_controls.SplitViewPaneClosingEventArgs
StackLayout = _winrt_microsoft_ui_xaml_controls.StackLayout
StackPanel = _winrt_microsoft_ui_xaml_controls.StackPanel
StyleSelector = _winrt_microsoft_ui_xaml_controls.StyleSelector
SwapChainBackgroundPanel = _winrt_microsoft_ui_xaml_controls.SwapChainBackgroundPanel
SwapChainPanel = _winrt_microsoft_ui_xaml_controls.SwapChainPanel
SwipeControl = _winrt_microsoft_ui_xaml_controls.SwipeControl
SwipeItem = _winrt_microsoft_ui_xaml_controls.SwipeItem
SwipeItemInvokedEventArgs = _winrt_microsoft_ui_xaml_controls.SwipeItemInvokedEventArgs
SwipeItems = _winrt_microsoft_ui_xaml_controls.SwipeItems
winrt.system._mixin_mutable_sequence(SwipeItems)
SymbolIcon = _winrt_microsoft_ui_xaml_controls.SymbolIcon
SymbolIconSource = _winrt_microsoft_ui_xaml_controls.SymbolIconSource
TabView = _winrt_microsoft_ui_xaml_controls.TabView
TabViewItem = _winrt_microsoft_ui_xaml_controls.TabViewItem
TabViewItemTemplateSettings = _winrt_microsoft_ui_xaml_controls.TabViewItemTemplateSettings
TabViewTabCloseRequestedEventArgs = _winrt_microsoft_ui_xaml_controls.TabViewTabCloseRequestedEventArgs
TabViewTabDragCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.TabViewTabDragCompletedEventArgs
TabViewTabDragStartingEventArgs = _winrt_microsoft_ui_xaml_controls.TabViewTabDragStartingEventArgs
TabViewTabDroppedOutsideEventArgs = _winrt_microsoft_ui_xaml_controls.TabViewTabDroppedOutsideEventArgs
TeachingTip = _winrt_microsoft_ui_xaml_controls.TeachingTip
TeachingTipClosedEventArgs = _winrt_microsoft_ui_xaml_controls.TeachingTipClosedEventArgs
TeachingTipClosingEventArgs = _winrt_microsoft_ui_xaml_controls.TeachingTipClosingEventArgs
TeachingTipTemplateSettings = _winrt_microsoft_ui_xaml_controls.TeachingTipTemplateSettings
TextBlock = _winrt_microsoft_ui_xaml_controls.TextBlock
TextBox = _winrt_microsoft_ui_xaml_controls.TextBox
TextBoxBeforeTextChangingEventArgs = _winrt_microsoft_ui_xaml_controls.TextBoxBeforeTextChangingEventArgs
TextBoxSelectionChangingEventArgs = _winrt_microsoft_ui_xaml_controls.TextBoxSelectionChangingEventArgs
TextBoxTextChangingEventArgs = _winrt_microsoft_ui_xaml_controls.TextBoxTextChangingEventArgs
TextChangedEventArgs = _winrt_microsoft_ui_xaml_controls.TextChangedEventArgs
TextCommandBarFlyout = _winrt_microsoft_ui_xaml_controls.TextCommandBarFlyout
TextCompositionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.TextCompositionChangedEventArgs
TextCompositionEndedEventArgs = _winrt_microsoft_ui_xaml_controls.TextCompositionEndedEventArgs
TextCompositionStartedEventArgs = _winrt_microsoft_ui_xaml_controls.TextCompositionStartedEventArgs
TextControlCopyingToClipboardEventArgs = _winrt_microsoft_ui_xaml_controls.TextControlCopyingToClipboardEventArgs
TextControlCuttingToClipboardEventArgs = _winrt_microsoft_ui_xaml_controls.TextControlCuttingToClipboardEventArgs
TextControlPasteEventArgs = _winrt_microsoft_ui_xaml_controls.TextControlPasteEventArgs
TimePickedEventArgs = _winrt_microsoft_ui_xaml_controls.TimePickedEventArgs
TimePicker = _winrt_microsoft_ui_xaml_controls.TimePicker
TimePickerFlyout = _winrt_microsoft_ui_xaml_controls.TimePickerFlyout
TimePickerFlyoutPresenter = _winrt_microsoft_ui_xaml_controls.TimePickerFlyoutPresenter
TimePickerSelectedValueChangedEventArgs = _winrt_microsoft_ui_xaml_controls.TimePickerSelectedValueChangedEventArgs
TimePickerValueChangedEventArgs = _winrt_microsoft_ui_xaml_controls.TimePickerValueChangedEventArgs
ToggleMenuFlyoutItem = _winrt_microsoft_ui_xaml_controls.ToggleMenuFlyoutItem
ToggleSplitButton = _winrt_microsoft_ui_xaml_controls.ToggleSplitButton
ToggleSplitButtonIsCheckedChangedEventArgs = _winrt_microsoft_ui_xaml_controls.ToggleSplitButtonIsCheckedChangedEventArgs
ToggleSwitch = _winrt_microsoft_ui_xaml_controls.ToggleSwitch
ToolTip = _winrt_microsoft_ui_xaml_controls.ToolTip
ToolTipService = _winrt_microsoft_ui_xaml_controls.ToolTipService
TreeView = _winrt_microsoft_ui_xaml_controls.TreeView
TreeViewCollapsedEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewCollapsedEventArgs
TreeViewDragItemsCompletedEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewDragItemsCompletedEventArgs
TreeViewDragItemsStartingEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewDragItemsStartingEventArgs
TreeViewExpandingEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewExpandingEventArgs
TreeViewItem = _winrt_microsoft_ui_xaml_controls.TreeViewItem
TreeViewItemInvokedEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewItemInvokedEventArgs
TreeViewItemTemplateSettings = _winrt_microsoft_ui_xaml_controls.TreeViewItemTemplateSettings
TreeViewList = _winrt_microsoft_ui_xaml_controls.TreeViewList
TreeViewNode = _winrt_microsoft_ui_xaml_controls.TreeViewNode
TreeViewSelectionChangedEventArgs = _winrt_microsoft_ui_xaml_controls.TreeViewSelectionChangedEventArgs
TwoPaneView = _winrt_microsoft_ui_xaml_controls.TwoPaneView
UIElementCollection = _winrt_microsoft_ui_xaml_controls.UIElementCollection
winrt.system._mixin_mutable_sequence(UIElementCollection)
UniformGridLayout = _winrt_microsoft_ui_xaml_controls.UniformGridLayout
UserControl = _winrt_microsoft_ui_xaml_controls.UserControl
VariableSizedWrapGrid = _winrt_microsoft_ui_xaml_controls.VariableSizedWrapGrid
Viewbox = _winrt_microsoft_ui_xaml_controls.Viewbox
VirtualizingLayout = _winrt_microsoft_ui_xaml_controls.VirtualizingLayout
VirtualizingLayoutContext = _winrt_microsoft_ui_xaml_controls.VirtualizingLayoutContext
VirtualizingPanel = _winrt_microsoft_ui_xaml_controls.VirtualizingPanel
VirtualizingStackPanel = _winrt_microsoft_ui_xaml_controls.VirtualizingStackPanel
WebView2 = _winrt_microsoft_ui_xaml_controls.WebView2
WrapGrid = _winrt_microsoft_ui_xaml_controls.WrapGrid
XamlControlsResources = _winrt_microsoft_ui_xaml_controls.XamlControlsResources
IAnimatedVisual = _winrt_microsoft_ui_xaml_controls.IAnimatedVisual
IAnimatedVisual2 = _winrt_microsoft_ui_xaml_controls.IAnimatedVisual2
IAnimatedVisualSource = _winrt_microsoft_ui_xaml_controls.IAnimatedVisualSource
IAnimatedVisualSource2 = _winrt_microsoft_ui_xaml_controls.IAnimatedVisualSource2
IAnimatedVisualSource3 = _winrt_microsoft_ui_xaml_controls.IAnimatedVisualSource3
ICommandBarElement = _winrt_microsoft_ui_xaml_controls.ICommandBarElement
IDynamicAnimatedVisualSource = _winrt_microsoft_ui_xaml_controls.IDynamicAnimatedVisualSource
IInsertionPanel = _winrt_microsoft_ui_xaml_controls.IInsertionPanel
IItemContainerMapping = _winrt_microsoft_ui_xaml_controls.IItemContainerMapping
IKeyIndexMapping = _winrt_microsoft_ui_xaml_controls.IKeyIndexMapping
INavigate = _winrt_microsoft_ui_xaml_controls.INavigate
IScrollAnchorProvider = _winrt_microsoft_ui_xaml_controls.IScrollAnchorProvider
ISemanticZoomInformation = _winrt_microsoft_ui_xaml_controls.ISemanticZoomInformation
CalendarViewDayItemChangingEventHandler = typing.Callable[[typing.Optional[CalendarView], typing.Optional[CalendarViewDayItemChangingEventArgs]], None]
CleanUpVirtualizedItemEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[CleanUpVirtualizedItemEventArgs]], None]
ContextMenuOpeningEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[ContextMenuEventArgs]], None]
DragItemsStartingEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[DragItemsStartingEventArgs]], None]
HubSectionHeaderClickEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[HubSectionHeaderClickEventArgs]], None]
ItemClickEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[ItemClickEventArgs]], None]
ListViewItemToKeyHandler = typing.Callable[[typing.Optional[winrt.system.Object]], str]
ListViewKeyToItemHandler = typing.Callable[[str], "windows_foundation.IAsyncOperation[winrt.system.Object]"]
SectionsInViewChangedEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[SectionsInViewChangedEventArgs]], None]
SelectionChangedEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[SelectionChangedEventArgs]], None]
SemanticZoomViewChangedEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[SemanticZoomViewChangedEventArgs]], None]
TextChangedEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[TextChangedEventArgs]], None]
TextControlPasteEventHandler = typing.Callable[[typing.Optional[winrt.system.Object], typing.Optional[TextControlPasteEventArgs]], None]
